@@ -11,3 +11,6 @@ from scimulti import *
 
 # statistics calculation
 from scistat import *
+
+# various
+from sciop import *
