@@ -79,9 +79,9 @@ def multifunc(function,allvars,procaxis,vardims):
                 # if a function has to be applied on that dimension, 
                 #only add an 'axis' for that dimension
                 if procaxis[ivar] == True:
-                    print 1,ivar,  allvars[ivar].shape
+                    # print 1,ivar,  allvars[ivar].shape
                     allvars[ivar] = allvars[ivar][newaxis,:]
-                    print ivar,  allvars[ivar].shape
+                    # print ivar,  allvars[ivar].shape
                 # else: length of dimension is 
                 # considered the same for all variables! 
                 # so multiple copies are made from the dimension 
@@ -92,10 +92,10 @@ def multifunc(function,allvars,procaxis,vardims):
                     for ivar2,evar2 in enumerate(allvars):
                         if idim in vardims[ivar2]:
                             if ldone == False:
-                                print 2,ivar, allvars[ivar].shape
+                                # print 2,ivar, allvars[ivar].shape
                                 # dimension length: evar2.shape[vardims[ivar2].index(idim) 
                                 allvars[ivar] = repeat(allvars[ivar][newaxis,:],evar2.shape[vardims[ivar2].index(idim)],0)
-                                print ivar,  allvars[ivar].shape
+                                # print ivar,  allvars[ivar].shape
                             ldone = True
                 vardims[ivar][idim] = -1
                 for idim2 in range(len(vardims[ivar])): #reversed(range(dimcount)):
@@ -106,13 +106,13 @@ def multifunc(function,allvars,procaxis,vardims):
     # put dimensions of all variables arrays in the same order 
     # as the standard order (which is implicitely given by vardims)
 
-    for ivar,evar in enumerate(allvars):
-        print evar.shape, vardims[ivar]
+    # for ivar,evar in enumerate(allvars):
+    #     print evar.shape, vardims[ivar]
     for ivar,evar in enumerate(allvars):
         allvars[ivar] = transpose(evar,vardims[ivar])
-    for ivar,evar in enumerate(allvars):
-        print 'shape before transposition:',evar.shape, vardims[ivar]
-        print 'procaxis:', procaxis
+    # for ivar,evar in enumerate(allvars):
+    #     print 'shape before transposition:',evar.shape, vardims[ivar]
+    #     print 'procaxis:', procaxis
 
 
     # if a certain dimension has
@@ -123,7 +123,7 @@ def multifunc(function,allvars,procaxis,vardims):
             maxdim = max(shape(evar)[idim],maxdim)
         for ivar,evar in enumerate(allvars):
             if ((shape(evar)[idim] == 1) & (maxdim > 1)):
-                print maxdim,idim
+                # print maxdim,idim
                 allvars[ivar] = repeat(allvars[ivar],maxdim,idim)
                 # tmpdim = range(len(procaxis))
                 # tmpdim[idim] = 0
@@ -138,9 +138,9 @@ def multifunc(function,allvars,procaxis,vardims):
                 #     inv[edim2] = idim2
                 # allvars[ivar] = transpose(allvars[ivar],inv)
 
-    for ivar,evar in enumerate(allvars):
-        print 'shape after expansion:',evar.shape, vardims[ivar]
-        print 'procaxis:', procaxis
+    # for ivar,evar in enumerate(allvars):
+    #     print 'shape after expansion:',evar.shape, vardims[ivar]
+    #     print 'procaxis:', procaxis
 
     
     # now transpose all matrices in a similar way in such a way that the dimensions 
