@@ -21,7 +21,7 @@ def steinalp(f,numfac):
     fshp = frav.shape #np.shape(frav)[:numfac]
     nmshape = 2**numfac
     lshf = numfac
-    print 'frav.shape',frav.shape
+    # print 'frav.shape',frav.shape
     
     ishape = 0
     while nmshape > 1:
